@@ -92,8 +92,11 @@ class AppSetup(Controller):
     def deploy(self):
         self.app.log.info(f'deploying plugin')
         try:
-            plugin_name = os.path.dirname(self.backend_path)
+            plugin_name = os.path.split(os.getcwd())[1]
+            print(plugin_name)
             backend_image_tag = f'{plugin_name}-backend:latest'
+            print(backend_image_tag)
+            print(self.container_registry)
             os.system(f'cd {self.backend_path}')
             os.system(f'docker build -t {backend_image_tag} .')
             os.system(f'docker tag {backend_image_tag} {self.container_registry}/{backend_image_tag}')
